/*
 * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
 * @license AGPL-3.0
 *
 * This code is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with OX App Suite. If not, see <https://www.gnu.org/licenses/agpl-3.0.txt>.
 *
 * Any use of the work other than as authorized under this license or copyright law is prohibited.
 *
 */



package com.openexchange.office.filter.core;

import java.io.ByteArrayInputStream;
import java.io.IOException;
import java.io.InputStream;
import java.util.zip.ZipEntry;
import java.util.zip.ZipInputStream;
import org.apache.commons.io.IOUtils;
import com.openexchange.office.filter.api.FilterException;
import com.openexchange.office.filter.api.FilterException.ErrorCode;

public class DocumentComplexity {

    public static ByteArrayInputStream checkDocumentComplexity(InputStream _inputStream, long maxAllowedXmlSizeMatchingComplexity, long maxAllowedXmlSizeMatchingMemory)
       	throws FilterException {

        if(maxAllowedXmlSizeMatchingComplexity<=0&&maxAllowedXmlSizeMatchingMemory<=0&&_inputStream instanceof ByteArrayInputStream) {
            return (ByteArrayInputStream)_inputStream;
        }

        ByteArrayInputStream returnValue = null;

        int xmlFileSize = 0;

        byte[] bytes;

        try {
			bytes = IOUtils.toByteArray(_inputStream);
		} catch (IOException e1) {
            throw new FilterException("", ErrorCode.COMPLEXITY_TOO_HIGH);
		} finally {
	        IOUtils.closeQuietly(_inputStream);
		}

        final InputStream _zipInputStream = new ByteArrayInputStream(bytes);
        final ZipInputStream zipInputStream = new ZipInputStream(_zipInputStream);

        ZipEntry zipEntry = null;
        final byte[] buffer = new byte[0x10000];  // 64kb buffer

        try {
			while((zipEntry = zipInputStream.getNextEntry())!=null) {

				int read;

				final String zipEntryName = zipEntry.getName();
				if(zipEntryName.endsWith(".xml")) {
		        	while((read = zipInputStream.read(buffer))>=0) {
		        		xmlFileSize += read;
		        	}
		        }
			    zipInputStream.closeEntry();
			    if((maxAllowedXmlSizeMatchingComplexity>0)&&(xmlFileSize>maxAllowedXmlSizeMatchingComplexity)) {
		            throw new FilterException("", ErrorCode.COMPLEXITY_TOO_HIGH);
			    }
			}
            if((maxAllowedXmlSizeMatchingMemory>0)&&(xmlFileSize>maxAllowedXmlSizeMatchingMemory)) {
                throw new FilterException("", ErrorCode.COMPLEXITY_TOO_HIGH, (maxAllowedXmlSizeMatchingMemory));
            }
			returnValue = new ByteArrayInputStream(bytes);
        } catch (IOException e) {
            throw new FilterException("", ErrorCode.COMPLEXITY_TOO_HIGH);
		} finally {
			try {
				zipInputStream.close();
			} catch (IOException e) {

			}
			IOUtils.closeQuietly(_zipInputStream);
		}
        return returnValue;
    }
}
